"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.multilineArrayPrinter = void 0;
const insert_new_lines_1 = require("./insert-new-lines");
const jsplugin_1 = require("./jsplugin");
const debug = !!process.env.NEW_LINE_DEBUG;
let jsPrinter;
function wrapInJsPrinterCall(property, subProperty) {
    return (...args) => {
        var _a;
        const originalPrinter = (0, jsplugin_1.getOriginalPrinter)();
        if (property === 'print') {
            const path = args[0];
            const options = args[1];
            const originalOutput = originalPrinter.print.call(jsPrinter, path, {
                ...options,
                parser: 'typescript',
                astFormat: 'estree',
            }, ...args.slice(2));
            // return originalOutput;
            return (0, insert_new_lines_1.printWithMultilineArrays)(originalOutput, args[0], debug);
        }
        else {
            let thisParent = jsPrinter;
            let printerProp = originalPrinter[property];
            if (subProperty) {
                thisParent = printerProp;
                printerProp = printerProp[subProperty];
            }
            try {
                return (_a = printerProp) === null || _a === void 0 ? void 0 : _a.apply(thisParent, args);
            }
            catch (error) {
                const newError = new Error(`Failed to wrap JS printer call for property "${property}" ${subProperty ? `and subProperty "${subProperty}"` : ''}: \n`);
                if (error instanceof Error && error.stack) {
                    newError.stack = newError.message + error.stack;
                }
                throw newError;
            }
        }
    };
}
const handleComments = {
    // the avoidAstMutation property is not defined in the types
    // @ts-expect-error
    avoidAstMutation: true,
    endOfLine: wrapInJsPrinterCall('handleComments', 'endOfLine'),
    ownLine: wrapInJsPrinterCall('handleComments', 'ownLine'),
    remaining: wrapInJsPrinterCall('handleComments', 'remaining'),
};
exports.multilineArrayPrinter = new Proxy({}, {
    get: (target, property) => {
        /**
         * "handleComments" is the only printer property which isn't a callback function, so for
         * simplicity, ignore it.
         */
        if (property === 'handleComments') {
            return handleComments;
        }
        /** We have to return a callback so that we can extract the jsPlugin from the options argument */
        return wrapInJsPrinterCall(property);
    },
});
